==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QHideEvent_shell.cpp <==
#include "QHideEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QHideEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHideEvent")
    QHideEvent *_ptr = reinterpret_cast<QHideEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QHideEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QHideEvent_shell) ); }

jmethodID QHideEvent_shell::__shell_javaMethod(int pos) const { return QHideEvent_shell::__shell()->javaMethod(typeid(QHideEvent), pos); }

// emitting (writeShellConstructor)
QHideEvent_shell::QHideEvent_shell()
    : QHideEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QHideEvent::QHideEvent_shell()", QHideEvent_shell::__shell())
    QHideEvent_shell::__shell()->constructed(typeid(QHideEvent));
}

QHideEvent_shell::QHideEvent_shell(const QHideEvent& arg__1)
    : QHideEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QHideEvent::QHideEvent_shell(const QHideEvent& arg__1)", QHideEvent_shell::__shell())
    QHideEvent_shell::__shell()->constructed(typeid(QHideEvent));
}

// emitting (writeShellDestructor)
QHideEvent_shell::~QHideEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QHideEvent::~QHideEvent()", QHideEvent_shell::__shell())
    QHideEvent_shell::__shell()->destructed(typeid(QHideEvent));
}

void QHideEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QHideEvent_shell*>(ptr)->QHideEvent_shell::__shell()->tryDeleteShell(typeid(QHideEvent));
}

// emitting Virtual overrides (virtualFunctions)
QHideEvent* QHideEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QHideEvent::clone()const", QHideEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QHideEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QHideEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QHideEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QHideEvent_shell::__shell()->warnForMethod("QHideEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QHideEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QHideEvent::clone();
        }
    }else{
        return QHideEvent::clone();
    }
}

void QHideEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QHideEvent::", QHideEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QHideEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QHideEvent_shell::__shell()->warnForMethod("QHideEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QHideEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QHideEvent_access::__qt_assign_cref_QHideEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QHideEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QHideEvent>(__jni_env, other0);
    QHideEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QHideEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QHideEvent* __qt_return_value = QHideEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QHideEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QHideEvent()
void __qt_construct_QHideEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHideEvent()")
    Q_UNUSED(__java_arguments)
    QHideEvent *__qt_this = new(__qtjambi_ptr) QHideEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QHideEvent(QHideEvent)
void __qt_construct_QHideEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHideEvent(QHideEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QHideEvent& __qt_arg__1 = qtjambi_cast<const QHideEvent& >(__jni_env, arg__1);
    QHideEvent *__qt_this = new(__qtjambi_ptr) QHideEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QHideEvent_shell
void __qt_destruct_QHideEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHideEvent")
    reinterpret_cast<QHideEvent_shell*>(ptr)->~QHideEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHideEvent::QHideEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QHideEvent_initialize_1native__Lio_qt_gui_QHideEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHideEvent::QHideEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHideEvent_0, sizeof(QHideEvent_shell), typeid(QHideEvent), true, &deleter_QHideEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHideEvent::QHideEvent(QHideEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QHideEvent_initialize_1native__Lio_qt_gui_QHideEvent_2Lio_qt_gui_QHideEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHideEvent::QHideEvent(QHideEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHideEvent_1, sizeof(QHideEvent_shell), typeid(QHideEvent), true, &deleter_QHideEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHideEvent::operator=(QHideEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QHideEvent_assign_1native_1cref_1QHideEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHideEvent *__qt_this = QtJambiAPI::objectFromNativeId<QHideEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHideEvent::operator=(QHideEvent)", __qt_this)
        static_cast<QHideEvent_access*>(__qt_this)->__qt_assign_cref_QHideEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHideEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QHideEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHideEvent *__qt_this = QtJambiAPI::objectFromNativeId<QHideEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHideEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QHideEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QHideEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QHideEvent>("QHideEvent", "io/qt/gui/QHideEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QHideEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QHideEvent, {
        ConstructorInfo(&__qt_construct_QHideEvent_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QHideEvent_1, "Lio/qt/gui/QHideEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHideEvent);
    registerSizeOfShell(typeId, sizeof(QHideEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QHideEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QHideEvent_shell.cpp <==
#include "QHideEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QHideEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHideEvent")
    QHideEvent *_ptr = reinterpret_cast<QHideEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QHideEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QHideEvent_shell) ); }

jmethodID QHideEvent_shell::__shell_javaMethod(int pos) const { return QHideEvent_shell::__shell()->javaMethod(typeid(QHideEvent), pos); }

// emitting (writeShellConstructor)
QHideEvent_shell::QHideEvent_shell()
    : QHideEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QHideEvent::QHideEvent_shell()", QHideEvent_shell::__shell())
    QHideEvent_shell::__shell()->constructed(typeid(QHideEvent));
}

QHideEvent_shell::QHideEvent_shell(const QHideEvent& arg__1)
    : QHideEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QHideEvent::QHideEvent_shell(const QHideEvent& arg__1)", QHideEvent_shell::__shell())
    QHideEvent_shell::__shell()->constructed(typeid(QHideEvent));
}

// emitting (writeShellDestructor)
QHideEvent_shell::~QHideEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QHideEvent::~QHideEvent()", QHideEvent_shell::__shell())
    QHideEvent_shell::__shell()->destructed(typeid(QHideEvent));
}

void QHideEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QHideEvent_shell*>(ptr)->QHideEvent_shell::__shell()->tryDeleteShell(typeid(QHideEvent));
}

// emitting Virtual overrides (virtualFunctions)
QHideEvent* QHideEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QHideEvent::clone()const", QHideEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QHideEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QHideEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QHideEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QHideEvent_shell::__shell()->warnForMethod("QHideEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QHideEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QHideEvent::clone();
        }
    }else{
        return QHideEvent::clone();
    }
}

void QHideEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QHideEvent::", QHideEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QHideEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QHideEvent_shell::__shell()->warnForMethod("QHideEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QHideEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QHideEvent_access::__qt_assign_cref_QHideEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QHideEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QHideEvent>(__jni_env, other0);
    QHideEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QHideEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QHideEvent* __qt_return_value = QHideEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QHideEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QHideEvent()
void __qt_construct_QHideEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHideEvent()")
    Q_UNUSED(__java_arguments)
    QHideEvent *__qt_this = new(__qtjambi_ptr) QHideEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QHideEvent::QHideEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QHideEvent_initialize_1native__Lio_qt_gui_QHideEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHideEvent::QHideEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHideEvent, sizeof(QHideEvent_shell), typeid(QHideEvent), true, &deleter_QHideEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QHideEvent(QHideEvent)
void __qt_construct_QHideEvent_cref_QHideEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHideEvent(QHideEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QHideEvent& __qt_arg__1 = qtjambi_cast<const QHideEvent& >(__jni_env, arg__1);
    QHideEvent *__qt_this = new(__qtjambi_ptr) QHideEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHideEvent::QHideEvent(QHideEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QHideEvent_initialize_1native__Lio_qt_gui_QHideEvent_2Lio_qt_gui_QHideEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHideEvent::QHideEvent(QHideEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHideEvent_cref_QHideEvent, sizeof(QHideEvent_shell), typeid(QHideEvent), true, &deleter_QHideEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QHideEvent_shell
void __qt_destruct_QHideEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHideEvent")
    reinterpret_cast<QHideEvent_shell*>(ptr)->~QHideEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHideEvent::operator=(QHideEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QHideEvent_assign_1native_1cref_1QHideEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHideEvent *__qt_this = QtJambiAPI::objectFromNativeId<QHideEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHideEvent::operator=(QHideEvent)", __qt_this)
        static_cast<QHideEvent_access*>(__qt_this)->__qt_assign_cref_QHideEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHideEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QHideEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHideEvent *__qt_this = QtJambiAPI::objectFromNativeId<QHideEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHideEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QHideEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QHideEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QHideEvent>("QHideEvent", "io/qt/gui/QHideEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QHideEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QHideEvent, {
        ConstructorInfo(&__qt_construct_QHideEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QHideEvent_cref_QHideEvent, "Lio/qt/gui/QHideEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHideEvent);
    registerSizeOfShell(typeId, sizeof(QHideEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QHideEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
